Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
privacyforms_pdf / __init__.py | (no class) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | (no class) |  | 100% | 141 | 0 | 2 |  | 100% | 30 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormNotFoundError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldNotFoundError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormValidationError |  | 100% | 6 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldGeometry |  | 100% | 5 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFField |  | 100% | 5 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormField |  | 100% | 10 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormData |  | 100% | 8 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor |  | 96% | 214 | 8 | 0 |  | 90% | 124 | 8 |  | 94%
privacyforms_pdf / extractor.py | (no class) |  | 100% | 77 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 98% | 469 | 8 | 4 |  | 92% | 160 | 8 |  | 97%

No items found using the specified filter.